@@ -18,7 +18,7 @@ class Issue23Test extends TestCase
      */
     private $geocoder;
 
-    public function setUp()
+    public function setUp(): void
     {
         PhoneNumberUtil::resetInstance();
         $this->phoneUtil = PhoneNumberUtil::getInstance();
