@@ -1,4 +1,5 @@
 <?php
+
 namespace libphonenumber\Tests\Issues;
 
 use libphonenumber\PhoneNumber;
@@ -12,7 +13,7 @@ class Issue35Test extends TestCase
      */
     private $phoneUtil;
 
-    public function setUp()
+    public function setUp(): void
     {
         PhoneNumberUtil::resetInstance();
         $this->phoneUtil = PhoneNumberUtil::getInstance();
