@@ -14,7 +14,7 @@ class AsYouTypeFormatterTest extends TestCase
      */
     protected $phoneUtil;
 
-    public function setUp()
+    public function setUp(): void
     {
         PhoneNumberUtil::resetInstance();
         $this->phoneUtil = PhoneNumberUtil::getInstance(
@@ -658,16 +658,16 @@ class AsYouTypeFormatterTest extends TestCase
         // +529011234567, proactively ensuring that no formatting is applied, where a format is chosen
         // that would otherwise have led to some digits being dropped.
         $formatter->clear();
-        $this->assertEquals("9", $formatter->inputDigit('9'));
-        $this->assertEquals("90", $formatter->inputDigit('0'));
-        $this->assertEquals("901", $formatter->inputDigit('1'));
-        $this->assertEquals("9011", $formatter->inputDigit('1'));
-        $this->assertEquals("90112", $formatter->inputDigit('2'));
-        $this->assertEquals("901123", $formatter->inputDigit('3'));
-        $this->assertEquals("9011234", $formatter->inputDigit('4'));
-        $this->assertEquals("90112345", $formatter->inputDigit('5'));
-        $this->assertEquals("901123456", $formatter->inputDigit('6'));
-        $this->assertEquals("9011234567", $formatter->inputDigit('7'));
+        $this->assertEquals('9', $formatter->inputDigit('9'));
+        $this->assertEquals('90', $formatter->inputDigit('0'));
+        $this->assertEquals('901', $formatter->inputDigit('1'));
+        $this->assertEquals('9011', $formatter->inputDigit('1'));
+        $this->assertEquals('90112', $formatter->inputDigit('2'));
+        $this->assertEquals('901123', $formatter->inputDigit('3'));
+        $this->assertEquals('9011234', $formatter->inputDigit('4'));
+        $this->assertEquals('90112345', $formatter->inputDigit('5'));
+        $this->assertEquals('901123456', $formatter->inputDigit('6'));
+        $this->assertEquals('9011234567', $formatter->inputDigit('7'));
 
         // +52 55 1234 5678
         $formatter->clear();
