@@ -9,7 +9,7 @@ use PHPUnit\Framework\TestCase;
 
 class UKTest extends TestCase
 {
-    public function setUp()
+    public function setUp(): void
     {
         PhoneNumberUtil::resetInstance();
     }
@@ -20,7 +20,7 @@ class UKTest extends TestCase
         $number->setCountryCode(44)->setNationalNumber(1614960000);
 
         $timeZone = PhoneNumberToTimeZonesMapper::getInstance();
-        $this->assertEquals(array('Europe/London'), $timeZone->getTimeZonesForNumber($number));
+        $this->assertEquals(['Europe/London'], $timeZone->getTimeZonesForNumber($number));
     }
 
     public function testNonGeocodableNumber()
@@ -30,12 +30,12 @@ class UKTest extends TestCase
 
         $timeZone = PhoneNumberToTimeZonesMapper::getInstance();
         $this->assertEquals(
-            array(
+            [
                 'Europe/Guernsey',
                 'Europe/Isle_of_Man',
                 'Europe/Jersey',
-                'Europe/London'
-            ),
+                'Europe/London',
+            ],
             $timeZone->getTimeZonesForNumber($number)
         );
     }
